<!DOCTYPE html>
<html>
<head>
<title>Steak House | Our Food</title>
<meta charset="iso-8859-1">
<link href="css/style.css" rel="stylesheet" type="text/css">
<!--[if IE 6]><link href="css/ie6.css" rel="stylesheet" type="text/css"><![endif]-->
<!--[if IE 7]><link href="css/ie7.css" rel="stylesheet" type="text/css"><![endif]-->
</head>
<body>
<div id="background">
  <div class="page">
    <div id="header">
      <ul class="navigation">
        <li><a class="active" href="food.html">OUR FOOD</a></li>
        <li><a href="beer.html">OUR BEER</a></li>
      </ul>
      <a id="logo" href="index.html"><img src="images/logo2.jpg" width="276" height="203" alt=""></a>
      <ul id="navigation">
        <li><a href="reservation.html">RESERVATION</a></li>
        <li><a href="contact.html">CONTACT US</a></li>
      </ul>
    </div>
    <div id="body">
      <div class="content">
        <div class="body">
          <h3>MENU</h3>
          <ul class="section">
            <li class="odd">
              <h2>CRAS TURPIS URNA</h2>
              <ul>
                <li>
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur</a></h2>
                  <span>$0.00</span>
                  <p> Praesent pretium venenatis nunc, eget porttitor tellus </p>
                </li>
                <li>
                  <h2><a href="#">Praesent id arcu ligula, at pulvinar est </a></h2>
                  <span>$0.00</span>
                  <p> Suspendisse potenti. Phasellus ac nibh massa </p>
                </li>
                <li>
                  <h2><a href="#">Cras turpis urna, luctus sed dapibus sed</a></h2>
                  <span>$0.00</span>
                  <p> Quisque accumsan, leo non aliquet pulvinar, ante justo </p>
                </li>
                <li>
                  <h2><a href="#">Nullam fermentum aliquet nibh quis </a></h2>
                  <span>$0.00</span>
                  <p> Donec blandit libero a felis gravida sed tempus est ultrices </p>
                </li>
                <li class="last">
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur</a></h2>
                  <span>$0.00</span>
                  <p> Praesent pretium venenatis nunc, eget porttitor tellus dignissim </p>
                </li>
              </ul>
            </li>
            <li>
              <h2>CRAS TURPIS URNA</h2>
              <ul>
                <li>
                  <h2><a href="#">Nullam fermentum aliquet nibh quis </a></h2>
                  <span>$0.00</span>
                  <p> Donec blandit libero a felis gravida sed tempus est ultrices </p>
                </li>
                <li>
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur adipi </a></h2>
                  <span>$0.00</span>
                  <p> Venenatis nunc, eget porttitor tellus dignissim et </p>
                </li>
                <li>
                  <h2><a href="#">Praesent id arcu ligula, at pulvinar justo gravida </a></h2>
                  <span>$0.00</span>
                  <p> Suspendisse potenti. Phasellus ac nibh massa </p>
                </li>
                <li>
                  <h2><a href="#">Cras turpis urna, luctus sed dapibus sed </a></h2>
                  <span>$0.00</span>
                  <p> Quisque accumsan, leo non aliquet pulvinar, ante justo ultricie </p>
                </li>
                <li class="last">
                  <h2><a href="#">Ullam fermentum aliquet nibh quis </a></h2>
                  <span>$0.00</span>
                  <p> Donec blandit libero a felis gravida sed tempus est ultrices </p>
                </li>
              </ul>
            </li>
            <li class="odd">
              <h2>CRAS TURPIS URNA</h2>
              <ul>
                <li>
                  <h2><a href="#">Nullam fermentum aliquet nibh quis </a></h2>
                  <span>$0.00</span>
                  <p> Donec blandit libero a felis gravida sed tempus est ultrices </p>
                </li>
                <li>
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur adipi </a></h2>
                  <span>$0.00</span>
                  <p> Venenatis nunc, eget porttitor tellus dignissim et </p>
                </li>
                <li>
                  <h2><a href="#">Praesent id arcu ligula, at pulvinar justo gravida </a></h2>
                  <span>$0.00</span>
                  <p> Suspendisse potenti. Phasellus ac nibh massa </p>
                </li>
                <li>
                  <h2><a href="#">Cras turpis urna, luctus sed dapibus sed </a></h2>
                  <span>$0.00</span>
                  <p> Quisque accumsan, leo non aliquet pulvinar, ante justo ultricie </p>
                </li>
                <li>
                  <h2><a href="#">Ullam fermentum aliquet nibh quis </a></h2>
                  <span>$0.00</span>
                  <p> Donec blandit libero a felis gravida sed tempus est ultrices </p>
                </li>
                <li class="last">
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur adipi </a></h2>
                  <span>$0.00</span>
                  <p> Praesent pretium venenatis nunc, eget porttitor tellus dignissim </p>
                </li>
              </ul>
            </li>
            <li>
              <h2>CRAS TURPIS URNA</h2>
              <ul>
                <li>
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur </a></h2>
                  <span>$0.00</span>
                  <p> Praesent pretium venenatis nunc, eget porttitor tellus </p>
                </li>
                <li>
                  <h2><a href="#">Praesent id arcu ligula, at pulvinar est </a></h2>
                  <span>$0.00</span>
                  <p> Suspendisse potenti. Phasellus ac nibh massa </p>
                </li>
                <li>
                  <h2><a href="#">Cras turpis urna, luctus sed dapibus sed </a></h2>
                  <span>$0.00</span>
                  <p> Quisque accumsan, leo non aliquet pulvinar, ante justo </p>
                </li>
                <li>
                  <h2><a href="#">Nullam fermentum aliquet nibh quis </a></h2>
                  <span>$0.00</span>
                  <p> Donec blandit libero a felis gravida sed tempus est ultrices </p>
                </li>
                <li>
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur </a></h2>
                  <span>$0.00</span>
                  <p> Praesent pretium venenatis nunc, eget porttitor tellus dignissim </p>
                </li>
                <li class="last">
                  <h2><a href="#">Lorem ipsum dolor sit amet, consectetur adipi </a></h2>
                  <span>$0.00</span>
                  <p> Venenatis nunc, eget porttitor tellus dignissim </p>
                </li>
              </ul>
            </li>
          </ul>
        </div>
      </div>
    </div>
    <div id="footer">
      <ul>
        <li class="first">
          <ul>
            <li><a href="index.html">Home</a></li>
            <li><a href="about.html">About</a></li>
            <li><a href="menu.html">Menu</a></li>
            <li><a href="beer.html">Beer</a></li>
            <li><a href="blog.html">Blog</a></li>
            <li><a href="contact.html">Contact Us</a></li>
          </ul>
        </li>
        <li> <span>Follow us:</span> <a href="#" class="facebook">&nbsp;</a> <a href="#" class="twitter">&nbsp;</a> </li>
      </ul>
      <p>Copyright &copy; 2012 <a href="#">Company Name</a> All rights reserved | Website Template By <a target="_blank" href="http://www.freewebsitetemplates.com/">freewebsitetemplates.com</a></p>
    </div>
  </div>
</div>
</body>
</html>
